@@ -2,7 +2,7 @@ import time
 
 from src import vyze
 from src.vyze import FieldType, FormatType, ResourceSpecials, ObjectType, read_layer_profile, ResourceInstance
-from src.vyze.tests.test_client import profile_str, service_url, system_url, test_universe
+from src.vyze.tests.test_system import profile_str, service_url, system_url, test_universe
 
 stream_url = 'ws://localhost:9131'
 # stream_url = 'wss://api.vyze.io/system'
